API References
==============

Phantoms
--------
Collection of virtual phantoms for quantitative MRI.

.. autosummary::
   :toctree: generated
   :nosignatures:

   mrtwin.shepplogan_phantom
   mrtwin.brainweb_phantom
   mrtwin.osf_phantom

Field maps
----------
Subroutines for the generation of field maps (B0, B1, Coil).

.. autosummary::
   :toctree: generated
   :nosignatures:

   mrtwin.b0field
   mrtwin.b1field
   mrtwin.sensmap

Miscellaneous
-------------
Other simulation utilities (rigid motion pattern, gradient system responses).

.. autosummary::
   :toctree: generated
   :nosignatures:

   mrtwin.rigid_motion
   mrtwin.generate_girf
